@@ -30,6 +30,7 @@ struct kanshi_profile_output {
 	float scale;
 	enum wl_output_transform transform;
 	bool adaptive_sync;
+	char *alias;
 };
 
 struct kanshi_profile_command {
@@ -46,7 +47,11 @@ struct kanshi_profile {
 };
 
 struct kanshi_config {
+	struct wl_list output_defaults;
 	struct wl_list profiles;
 };
 
+struct kanshi_config *parse_config(const char *path);
+void destroy_config(struct kanshi_config *config);
+
 #endif
